#
# spec file for package plexus-velocity
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           plexus-velocity
Version:        2.2.1
Release:        1.1
Summary:        Plexus Velocity Component
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://codehaus-plexus.github.io/plexus-velocity/
Source0:        https://github.com/codehaus-plexus/%{name}/archive/%{name}-%{version}.tar.gz
Source1:        %{name}-build.xml
Source2:        http://www.apache.org/licenses/LICENSE-2.0.txt
BuildRequires:  ant
BuildRequires:  apache-commons-collections
BuildRequires:  atinject
BuildRequires:  fdupes
BuildRequires:  java-devel >= 1.8
BuildRequires:  javapackages-local >= 6
BuildRequires:  objectweb-asm
BuildRequires:  sisu-inject
BuildRequires:  velocity-engine-core
BuildArch:      noarch

%description
This package provides Plexus Velocity component - a wrapper for
Apache Velocity template engine, which allows easy use of Velocity
by applications built on top of Plexus container.

%package javadoc
Summary:        API documentation for %{name}
Group:          Documentation/HTML

%description javadoc
This package provides %{summary}.

%prep
%setup -q -n %{name}-%{name}-%{version}

find -name '*.jar' -delete

cp -p %{SOURCE1} build.xml
cp -p %{SOURCE2} LICENSE

mkdir -p lib
build-jar-repository -s lib \
    atinject \
    commons-collections \
    objectweb-asm/asm \
    org.eclipse.sisu.inject \
    velocity-engine/velocity-engine-core

%build
ant jar javadoc

%install
# jar
install -dm 0755 %{buildroot}%{_javadir}/%{name}
install -pm 0644 target/%{name}-%{version}.jar %{buildroot}%{_javadir}/%{name}/%{name}.jar
# pom
install -dm 0755 %{buildroot}%{_mavenpomdir}/%{name}
%{mvn_install_pom} pom.xml %{buildroot}%{_mavenpomdir}/%{name}/%{name}.pom
%add_maven_depmap %{name}/%{name}.pom %{name}/%{name}.jar
# javadoc
install -dm 0755 %{buildroot}%{_javadocdir}/%{name}
cp -pr target/site/apidocs/* %{buildroot}%{_javadocdir}/%{name}/
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%license LICENSE

%files javadoc
%license LICENSE
%{_javadocdir}/%{name}

%changelog
* Wed Jun  4 2025 Fridrich Strba <fstrba@suse.com>
- Update to version 2.2.1
  * Dependency updates
    + Bump org.apache.velocity:velocity-engine-core from 2.4 to
    2.4.1
    + Bump org.apache.velocity:velocity-engine-core from 2.3 to 2.4
    + Bump org.eclipse.sisu:org.eclipse.sisu.inject from 0.9.0.M2 to
    0.9.0.M3
    + Bump org.codehaus.plexus:plexus from 19 to 20
    + Bump org.codehaus.plexus:plexus from 18 to 19
    + Bump org.codehaus.plexus:plexus from 17 to 18
    + Bump org.codehaus.plexus:plexus from 16 to 17
    + Bump release-drafter/release-drafter from 5 to 6
* Tue Jun  3 2025 Fridrich Strba <fstrba@suse.com>
- Add dependency on objectweb-asm to build with sisu 0.9.0.M4
* Thu Oct  3 2024 Fridrich Strba <fstrba@suse.com>
- Upgrade to version 2.1.0
  * Changes:
    + Upgrade to Velocity Engine 2.0
    + Upgrade Velocity Engine from 2.0 to 2.3
    + Move to JUnit5
* Sun May 26 2024 Fridrich Strba <fstrba@suse.com>
- Use the org.eclipse.sisu:org.eclipse.sisu.plexus artifact to
  avoid conflict/choise of providers
* Thu May 16 2024 Fridrich Strba <fstrba@suse.com>
- Use sisu-plexus instead of plexus-containers-container-default
- Clean up the spec file
* Tue Mar 29 2022 Fridrich Strba <fstrba@suse.com>
- Simplify the build file and remove tests which depend on
  apache-commons-lang
* Tue Mar 22 2022 Fridrich Strba <fstrba@suse.com>
- Build with java source and target levels 8
* Tue May 11 2021 Fridrich Strba <fstrba@suse.com>
- Do not compiler/run the test build against legacy guava20 any
  more
* Fri Mar 22 2019 Fridrich Strba <fstrba@suse.com>
- Initial packaging of plexus-velocity 1.2
- Generate and customize the ant build.xml file
